// This file is released under the 3-clause BSD license. See COPYING-BSD.
//=================================


// Test flags
//<-- XCOS TEST -->
//<-- NO CHECK ERROR OUTPUT -->

//Load xcos test diagram for dcm_to_quat tests
[macros,path] = libraryinfo('xcos_aerolib');
result = importXcosDiagram(path + "../tests/unit_tests" +"/dcm_to_quat.zcos");
assert_checktrue(result);

//This diagram uses 2 variables : 
//  dcm_in : input orientation matrix (from_workspace)
//  omega_in : input angular rate vector (from_workspace)
//  q_out : output quaternion (to_workspace)
//  qdot_out : output quaternion derivative (to_workspace)
//  q_out : output quaternion for simplified block (to_workspace)


// Generate test data
ang = CL_deg2rad(10);
dcm_in = CL_rot_angles2matrix(3,ang) // rotation around Z axis
omega_in = [1;1;1];

// Simulate
scicos_simulate(scs_m);

// Define expected values
exp_time = [0; 1; 2];
[cl_q cl_qdot] = CL_rot_matrix2quat(dcm_in, omega_in);
exp_q = [cl_q.r(1), cl_q.i(1), cl_q.i(2), cl_q.i(3)];
exp_qdot = [cl_qdot.r(1), cl_qdot.i(1), cl_qdot.i(2), cl_qdot.i(3)];


//Validate results
assert_checkequal(exp_time, q_out.time);
assert_checkequal(exp_q, q_out.values(1,:));
assert_checkequal(exp_q, q_out.values(2,:));
assert_checkequal(exp_q, q_out.values(3,:));
assert_checkequal(exp_qdot, qdot_out.values(1,:));
assert_checkequal(exp_qdot, qdot_out.values(2,:));
assert_checkequal(exp_qdot, qdot_out.values(3,:));
assert_checkequal(exp_q, q_out2.values(1,:));
assert_checkequal(exp_q, q_out2.values(2,:));
assert_checkequal(exp_q, q_out2.values(3,:));

